#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcre-heavy
version:              1.0.0.4
visibility:           public
id:                   pcre-heavy-1.0.0.4-6O7YEj9OVs8GTbCy56thV1
key:                  pcre-heavy-1.0.0.4-6O7YEj9OVs8GTbCy56thV1
license:              LicenseRef-PublicDomain
copyright:            2015-2025 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A PCRE-based regular expressions library with support for multiple matches and replacements.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/string-conversions convertible strings> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.

category:             Web
abi:                  e32eea9cdb4b113c25833a1b446b3bca
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pcre-heavy-1.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pcre-heavy-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pcre-heavy-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.4-6O7YEj9OVs8GTbCy56thV1
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    bytestring-0.11.5.3 pcre-light-0.4.1.3-FeKsoXtSiGM8384gdc4zs3
    string-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

